/*
 * BTLApplicationController.h
 * StoryWriter
 *
 * Controller for the Storywriter application. Also acts
 * as a delgate for the application
 * 
 * Created by Matthew Christensen on Thurs Sept 2 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

@interface BTLApplicationController : NSObject 
{
	NSMenu *appMenu;
	NSMenuItem *purchaseMenuItem;
	NSMenu *editMenu;
	NSMenuItem *completeMenuItem;
}

- (BOOL) validateMenuItem: (NSMenuItem *) menuItem;

// Send the default web browser to the purchase url for this Storywriter install
+ (void) gotoPurchaseURL;

#pragma mark Actions

// Send the browser to a URL where Storywriter can be purchased
- (IBAction) purchaseAction: (id) sender;

// Imports a file and creates a new document from it
- (IBAction) importAction: (id) sender;

// Create a new document from the default template
- (IBAction) newFromTemplate: (id) sender;

// Show the writing tips help
- (IBAction) showWritingTips: (id) sender;

// Show the primary help. We can't use the default method here
// because we have multiple help books
- (IBAction) showMainHelp: (id) sender;


#pragma mark NSApplicationDelegate

// Called when we're attempting to open an untitiled file
// we want to try opening our default file first
- (BOOL)applicationOpenUntitledFile:(NSApplication *)theApplication;

#pragma mark Utilities

// Create a blank document from the default tempate. Return true if
// succesful, false otherwise
- (bool) createBlankFromTemplate;

#pragma mark Utility methods

// Return true if we're on OS 10.2 or later
+ (BOOL)isJaguarOrNewer ;

// Return true if we're on OS 10.3 or later
+ (BOOL)isPantherOrNewer;

@end
