/*
 * BTLDocument.h
 * MooseTracker
 *
 * A Storywriter document. Note that we don't hold the data directly,
 * just a reference to the data
 * 
 * Created by Matthew Christensen on Tue Aug 03 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

#define TEXT_IMPORT_TYPE @"BTLTextImport"

@class BTLDataModel;
@class BTLDocumentInfoWindowController;
@class BTLMainWindowController;

extern NSString *BTLDataModelChangedNotification;

@interface BTLDocument : NSDocument
{
	BTLDataModel *dataModel;
	BTLDocumentInfoWindowController *documentInfoController;
	BTLMainWindowController *mainWindowController;

	// For revert
	NSString *savedType;
	uint32_t lastVersionId;
}

#pragma mark Actions
- (IBAction) storywriterRevertAction: (id) sender;

#pragma mark Accessors

- (BTLDataModel *) dataModel;
- (void) setDataModel: (BTLDataModel *) m;

- (BTLDocumentInfoWindowController *) documentInfoController;
- (void) setDocumentInfoController: (BTLDocumentInfoWindowController *) m;

#pragma mark Data manipulation

// Take the provided data and load it into ourselves
- (void) importFromData: (NSData *) d type: (NSString *) type;

#pragma mark Autosave

// Set our autosave flag in the document info,
// and start/stop our timer
- (void) setAutosave: (bool) state;

// Save the document as an autosave.
// Calls autosaveInFuture
- (void) autosave;

// Autosave in the future, in the number of minutes specified
// in the document info
- (void) startAutosaveTimer;

// Cancels any pending autosave action
- (void) cancelAutosaveTimer;
@end
