/*
 * BTLLayoutManager.h
 * StoryWriter
 *
 * Layout manager for Storywriter's text system.
 * 
 * Created by Matthew Christensen on Friday Aug 27 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */
#import <Cocoa/Cocoa.h>
#import "BTLTextViewDelegate.h"

@class BTLTextContainer;

@interface BTLLayoutManager : NSLayoutManager 
{

}

#pragma mark Notifications

- (void) documentInfoChanged: (NSNotification *) note;

// We want to listen to document info change notifications
- (void) updateDocumentInfo;

#pragma mark Line management

// Return the character range for the line at a glyph index
- (NSRange) lineForGlyphIndex: (unsigned) location;

// Find the character range of the first line of a container
- (NSRange) firstLineForContainer: (NSTextContainer *) container;

// Find the character range for the line at the given location in the given container
- (NSRange) lineForCharacterLocation: (unsigned) location;

#pragma mark Pagination

// Given the character name at that location, check to see 
// if we need to change the continued character name
- (void) updateCharacterNameForLocation: (unsigned) loc;

// Insert a page break at a given location
- (void) insertPageBreak: (unsigned) loc;

// Remove the page break for a given location
- (void) removePageBreak: (unsigned) loc;

// Return the text for a given page
- (NSString *) textForContainer: (NSTextContainer *) container;

- (void) paginateAllPages;

// Paginate the given container. This involes changing the textStorage object
// so can't be done while edit is locked
// Returns first location of modifications
- (unsigned) paginateContainer: (BTLTextContainer *) container;

// Paginate all containers starting at a given locatoin
// Returns true if pagination occurs at location, false if only after location
- (bool) paginateFromLocation: (unsigned) s;

#pragma mark Conversion

// Convert the text in this layout manager to a string, using spaces
// to produce the spacing. Delegate is used for status reporting, if non-nil
- (NSString *) convertToString: (id <BTLTextViewDelegate>) delegate;

@end

// Notification sent when we need a new page added
extern NSString *BTLAddPageNotification;
