/*
 * BTLTemplate.h
 * StoryWriter
 *
 * Describes a particular template. Contains one or more BTLStyle objects, a BTLPageTemplate 
 * for the title page, and a BTLPageTemplate object for other pages. It also receives a message, 
 * nextStyleForKeystroke, which handles the logic of switching between styles as the user types.
 * 
 * Created by Matthew Christensen on Tue Aug 24 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

@class BTLStyle;
@class BTLPageTemplate;
@class BTLTranslator;


@interface BTLTemplate : NSObject 
{
	// Name of this stemplate
	NSString *name;
	
	// Associated styles
	NSMutableArray *styles;
	NSMutableDictionary *stylesByName;
		
	// Template for title page
	BTLPageTemplate *titlePageTemplate;
	
	// Template for other pages
	BTLPageTemplate *pageTemplate;

	// Default style
	BTLStyle *defaultStyle;
	
	// Text translator
	BTLTranslator *textTranslator;
}

#pragma mark Initialization

// Designated initializer
- init;

#pragma mark Accessors

// Name of this template
- (NSString *) name;

// Return the default (starting) style
- (BTLStyle *) defaultStyle;

// Return the style for a name, or nil if no match
- (BTLStyle *) styleForName: (NSString *) name;

// Returns a (copy, for immutability) of all style associated with this template
- (NSArray *) styles;

// Returns a (copy, for immutability) of the title page template for this template
- (BTLPageTemplate *) titlePageTemplate;

// Returns a (copy, for immutability) of the page template for this template
- (BTLPageTemplate *) pageTemplate;

// Return a default list of autocomplete items for this template
- (NSArray *) defaultAutocompleteItems;

// Return our default font
- (NSFont *) defaultFont;

// Return the text translator for this template
- (BTLTranslator *) textTranslator;

// Return style for card titles
- (BTLStyle *) cardTitleStyle;

// Return style for card notes
- (BTLStyle *) notesStyle;

#pragma mark Utility methods
// Register a style with the template.
- (void) registerStyle: (BTLStyle *) s;

@end
